module tb_pwm ();
  
  localparam BITS = 11;
  
  logic [BITS-1:0] dataIn;
  logic dataOut;
  logic ck;
  logic rst;
  logic ce_out; 
  logic [0:9][BITS-1:0] sin4410k11bit;
  real  MAX_VALUE = 2**BITS;
  real  CK_PERIOD = 1.0/(MAX_VALUE*44100*2.0);
  int   nmbOfSamples = 1000; 
  
  pwm #(BITS
    )
    dut(
      .ck(ck),
      .arst(rst),
      .dataIn(dataIn),
      .dataOut(dataOut),
      .ce_out(ce_out)
    );
  
  initial begin
    $display("Testbench starting!!");
    if(BITS == 8)
      sin4410k11bit[0:9] = '{8'ha5, 8'hbc, 8'hbc, 8'ha5, 8'h80, 8'h5a, 8'h43, 8'h43, 8'ha5, 8'h7f};
    else if(BITS == 9)
      sin4410k11bit[0:9] = '{9'h14b, 9'h179, 9'h179, 9'h14b, 9'h100, 9'h0b4, 9'h086, 9'h086, 9'h0b4, 9'h0ff};
    else if(BITS == 10) 
      sin4410k11bit[0:9] = '{10'h296, 10'h2f3, 10'h2f3, 10'h296, 10'h200, 10'h169, 10'h10c, 10'h10c, 10'h169, 10'h1ff};
    else if(BITS == 11)
      sin4410k11bit[0:9] = '{11'h52c, 11'h5e6, 11'h5e6, 11'h52c, 11'h400, 11'h2d3, 11'h219, 11'h219, 11'h2d3, 11'h3ff};
    else if(BITS == 12)
      sin4410k11bit[0:9] = '{12'ha59, 12'hbcd, 12'hbcd, 12'ha59, 12'h800, 12'h5a6, 12'h432, 12'h432, 12'h5a6, 12'h7ff};    
    else 
      $fatal("BITS parameter wrong!!!");
    
    ck = 0;
    dataIn = 0;
    rst = 1;
    #(10*CK_PERIOD);
    rst = 0;
  end  
    
  
  always begin
    #CK_PERIOD ck = ~ck;
  end
  
  initial begin 
    @(negedge rst);
    for(int i = 0; i<nmbOfSamples; i++) begin
      @(posedge ce_out)
        dataIn = sin4410k11bit[i%10]; 
      if(i%1000==0)
        $info("Data number: %0d",i);
    end
    
    @(posedge ce_out)
      #(10*CK_PERIOD);
    
    $display("Testbench finish!!");
    $finish;
  end
endmodule