%Configure the script
plotFilters = 0;    %Set high if all filters should be plotted 
cicFilter4 = 1;     %Set high if the fourth filter should be a CIC filter
makeHDL = 0;        %Set high if HDL should be generated 
scaleOutput = 1;    %Set high if the output of each filter should be quantized
scaleCoeff = 1;     %Set high if the coefficinets should be quantized 
overflowAction = 1; %Set high if overflow action should be saturation, and low for wrap around
changeInverseSincStage  = 1;  %Set high if inverse Sinc filter should be the 3. filter, or low if 2. filter
plotIF = 0;

%Numeric type on the output of each filter, if scaleOutput is set high
cascadeOutNT1 = numerictype([],21,20);
cascadeOutNT2 = numerictype([],20,19);
cascadeOutNT3 = numerictype([],18,17);
if(cicFilter4 == 0)
    cascadeOutNT4 = numerictype([],18,17);
else 
    OutputWordLength4 = 19;
end
OutputWordLength5 = 18;
OutputWordLength6 = 17;
OutputWordLength7 = 16;

%Numeric type of filter coefficents, if scaleCoeff is set high
coeffData1 = numerictype([],22,20);
coeffData2 = numerictype([],20,18);
coeffData3 = numerictype([],16,14);
if(cicFilter4 == 0)
    coeffData4 = numerictype([],12,10);
end

%Variables
Filter = {0}; %Cell array for filter objects 
N=1;   
Fs = 44.1e3;  %Sampling frequency of 1. filter
Fb = Fs/2;    %Passband for 2.-7. filter 

%------1. FIlter design------
TW = 2050/(Fs/2);   % Transition width
Astop = 100;        % Minimum stopband attenuation
filtSpecs1  = fdesign.interpolator(2, 'Halfband', 'TW,Ast', TW, Astop);
Filter1 = design(filtSpecs1,'SystemObject',true);

Filter{N} = Filter1;
N = N+1;

if(changeInverseSincStage == 0) % 2. Inverse Sinc -> 3. Half-band
    %------2. Filter design------
    Fs = 2*Fs;   %Update sampling frequency
    Fp = Fb/Fs;  %Normalized passband 
    Fst= 1-Fp;   %Normalized stopband
    Astop = 100; % Minimum stopband attenuation
    filtSpecs2  = fdesign.interpolator(2,'Inverse-sinc Lowpass','fp,fst,ap,ast',Fp,Fst,0.0001, Astop);
    if(cicFilter4 == 1)  %Cange passband compasation depending on the number of CIC filters
        Filter2 = design(filtSpecs2,'SystemObject',true,'SincFrequencyFactor',0.409);
    else
        Filter2 = design(filtSpecs2,'SystemObject',true,'SincFrequencyFactor',0.1628);
    end
    
    Filter{N} = Filter2;
    N = N+1;

    %------3. Filter design------
    Fs = 2*Fs;        %Update sampling frequency
    TW = 1-Fb/(Fs/2); %Normalized transition-band
    Astop = 70;       %Minimum stopband attenuation
    filtSpecs3  = fdesign.interpolator(2, 'Halfband', 'TW,Ast', TW, Astop);
    Filter3 = design(filtSpecs3,'SystemObject',true);

    Filter{N} = Filter3;
    N = N+1;
else % 2. Half-band -> 3. Inverse Sinc 
    %------2. Filter design------
    Fs = 2*Fs;          %Update sampling frequency
    TW = 1-Fb/(Fs/2);   %Normalized transition-band
    Astop = 100;        %Minimum stopband attenuation
    filtSpecs2  = fdesign.interpolator(2, 'Halfband', 'TW,Ast', TW, Astop);
    Filter2 = design(filtSpecs2,'SystemObject',true);

    Filter{N} = Filter2;
    N = N+1;
    
    %------3. Filter design------
    Fs = 2*Fs;   %Update sampling frequency
    Fp = Fb/Fs;  %Normalized passband
    Fst= 1-Fp;   %Normalized stopband
    Astop = 70;  %Minimum stopband attenuation
    filtSpecs3  = fdesign.interpolator(2,'Inverse-sinc Lowpass','fp,fst,ap,ast',Fp,Fst,0.0001, Astop);
    if(cicFilter4 == 1)  %Cange passband compasation depending on the number of CIC filters
        Filter3 = design(filtSpecs3,'SystemObject',true,'SincFrequencyFactor',0.818);
    else
        Filter3 = design(filtSpecs3,'SystemObject',true,'SincFrequencyFactor',0.1628);
    end

    Filter{N} = Filter3;
    N = N+1;
end

%------4. Filter design------
if(cicFilter4== 1)  %4. filter is CIC
    Fs = 2*Fs;   %Update sampling frequency
    Fp = Fb/Fs;  %Normalized passband
    Astop = 55;  %Minimum stopband attenuation
    filtSpecs4  = fdesign.interpolator(2,'cic',1,'Fp,Ast',Fp, Astop);
    Filter4 = design(filtSpecs4,'SystemObject',true);
else    %4. filter is Half-band
    Fs = 2*Fs;        %Update sampling frequency
    TW = 1-Fb/(Fs/2); %Normalized transition-band
    Astop = 65;       %Minimum stopband attenuation
    filtSpecs4  = fdesign.interpolator(2, 'Halfband', 'TW,Ast', TW, Astop);
    Filter4 = design(filtSpecs4,'SystemObject',true);
end

Filter{N} = Filter4;
N = N+1;

%------5. Filter design------
Fs = 2*Fs;  %Update sampling frequency
Fp = Fb/Fs; %Normalized passband
Astop = 30; %Minimum stopband attenuation
filtSpecs5  = fdesign.interpolator(2,'cic',1,'Fp,Ast',Fp, Astop);
Filter5 = design(filtSpecs5,'SystemObject',true);

Filter{N} = Filter5;
N = N+1;

%------6. Filter design------
Fs = 2*Fs;  %Update sampling frequency
Fp = Fb/Fs; %Normalized passband
Astop = 30; %Minimum stopband attenuation
filtSpecs6  = fdesign.interpolator(2,'cic',1,'Fp,Ast',Fp, Astop);
Filter6 = design(filtSpecs6,'SystemObject',true);

Filter{N} = Filter6;
N = N+1;

%------7. Filter design------
Fs = 2*Fs;  %Update sampling frequency
Fp = Fb/Fs; %Normalized passband
Astop = 22; %Minimum stopband attenuation
filtSpecs7  = fdesign.interpolator(2,'cic',1,'Fp,Ast',Fp, Astop);
Filter7 = design(filtSpecs7,'SystemObject',true);

Filter{N} = Filter7;
N = N+1;

%Scale output of each filter with the set datatype 
if(scaleOutput)
    Filter1.FullPrecisionOverride = false;
    Filter1.OutputDataType        = 'Custom';
    Filter1.CustomOutputDataType  = cascadeOutNT1;
    
    Filter2.FullPrecisionOverride = false;
    Filter2.OutputDataType        = 'Custom';
    Filter2.CustomOutputDataType  = cascadeOutNT2;
    
    Filter3.FullPrecisionOverride = false;
    Filter3.OutputDataType        = 'Custom';
    Filter3.CustomOutputDataType  = cascadeOutNT3;
    
    if(cicFilter4 == 0)
        Filter4.FullPrecisionOverride = false;
        Filter4.OutputDataType        = 'Custom';
        Filter4.CustomOutputDataType  = cascadeOutNT4;
    else
        Filter4.FixedPointDataType = 'Minimum section word lengths';
        Filter4.OutputWordLength = OutputWordLength4;
    end
    
    Filter5.FixedPointDataType = 'Minimum section word lengths';
    Filter5.OutputWordLength = OutputWordLength5;
    
    Filter6.FixedPointDataType = 'Minimum section word lengths';
    Filter6.OutputWordLength = OutputWordLength6;
    
    Filter7.FixedPointDataType = 'Minimum section word lengths';
    Filter7.OutputWordLength = OutputWordLength7;
end

%Quantize the coefficents with the set datatype
if(scaleCoeff)
    Filter1.CoefficientsDataType  = 'Custom';
    Filter1.CustomCoefficientsDataType = coeffData1;
    
    Filter2.CoefficientsDataType  = 'Custom';
    Filter2.CustomCoefficientsDataType = coeffData2;
    
    Filter3.CoefficientsDataType  = 'Custom';
    Filter3.CustomCoefficientsDataType = coeffData3;
    
    if(cicFilter4 == 0)
        Filter4.CoefficientsDataType  = 'Custom';
        Filter4.CustomCoefficientsDataType = coeffData4;
    end
end

%Plot frequency response of each filter
if(plotFilters)
    fs = 44100;
    fvtool(Filter1,'Fs',2^1*fs,'Color','white','Arithmetic','fixed');
    fvtool(Filter2,'Fs',2^2*fs,'Color','white','Arithmetic','fixed');
    fvtool(Filter3,'Fs',2^3*fs,'Color','white','Arithmetic','fixed');
    fvtool(Filter4,'Fs',2^4*fs,'Color','white','Arithmetic','fixed');
    fvtool(Filter5,'Fs',2^5*fs,'Color','white','Arithmetic','fixed');
    fvtool(Filter6,'Fs',2^6*fs,'Color','white','Arithmetic','fixed');
    fvtool(Filter7,'Fs',2^7*fs,'Color','white','Arithmetic','fixed');
end

%Set overflow action for the non CIC filters 
if(overflowAction)
    Filter1.OverflowAction = 'Saturate';
    Filter2.OverflowAction = 'Saturate';
    Filter3.OverflowAction = 'Saturate';
    if(cicFilter4 == 0)
        Filter4.OverflowAction = 'Saturate';
    end
end

%Make a cascaded filter of all the filter objects
IF = cascade(Filter{:});

if(plotIF)
    %Plot frequency response of the complete IF 
    fvt = fvtool(IF,'Fs',2*Fs,'Color','white','Arithmetic','fixed');
    legend(fvt,'IF')
    fvt.NormalizeMagnitudeto1 = 'on';
    fvt.zoom([0,0.022,-0.001,0]);
end
%Generate HDL code of the filter
if(makeHDL)
    if(cicFilter4 == 0)
        workingdir = 'HdlFilter';
    else
        workingdir = 'HdlFilterCIC4';
    end
    inpFrameSz = 100e3;
    tVector    = linspace(0.005, 7.5, inpFrameSz);
    srcTBStim  = (chirp(tVector, 0, 1, 150))';

    generatehdl(IF, ...
        'TargetLanguage',        'Verilog',  ...
        'TargetDirectory',       workingdir, ...
        'InputDataType',         numerictype(1,16,15), ... 
        'OptimizeForHDL',        'on', ...
        'GenerateHDLTestbench',  'off', ...
        'TestBenchUserStimulus', srcTBStim, ...
        'ErrorMargin',           2);
end