
`timescale 1 ns / 1 ps

	module SD_DAC_v2_0 #
	(
		// Users to add parameters here
        // Parameters of Axi Slave Bus Interface S00_AXIS
        parameter integer C_S00_AXIS_TDATA_WIDTH    = 32,
		// User parameters ends
		// Do not modify the parameters beyond this line


		// Parameters of Axi Slave Bus Interface S00_AXI
		parameter integer C_S00_AXI_DATA_WIDTH	= 32,
		parameter integer C_S00_AXI_ADDR_WIDTH	= 4
	)
	(
		// Users to add ports here
        output wire dacOut,
        output wire irqUnderflow,
        output wire instabilityReset,
        // Ports of Axi Slave Bus Interface S00_AXIS
        input wire  s00_axis_aclk,
        input wire  s00_axis_aresetn,
        output wire  s00_axis_tready,
        input wire [C_S00_AXIS_TDATA_WIDTH-1 : 0] s00_axis_tdata,
        input wire  s00_axis_tvalid,
		// User ports ends
		// Do not modify the ports beyond this line


		// Ports of Axi Slave Bus Interface S00_AXI
		input wire  s00_axi_aclk,
		input wire  s00_axi_aresetn,
		input wire [C_S00_AXI_ADDR_WIDTH-1 : 0] s00_axi_awaddr,
		input wire [2 : 0] s00_axi_awprot,
		input wire  s00_axi_awvalid,
		output wire  s00_axi_awready,
		input wire [C_S00_AXI_DATA_WIDTH-1 : 0] s00_axi_wdata,
		input wire [(C_S00_AXI_DATA_WIDTH/8)-1 : 0] s00_axi_wstrb,
		input wire  s00_axi_wvalid,
		output wire  s00_axi_wready,
		output wire [1 : 0] s00_axi_bresp,
		output wire  s00_axi_bvalid,
		input wire  s00_axi_bready,
		input wire [C_S00_AXI_ADDR_WIDTH-1 : 0] s00_axi_araddr,
		input wire [2 : 0] s00_axi_arprot,
		input wire  s00_axi_arvalid,
		output wire  s00_axi_arready,
		output wire [C_S00_AXI_DATA_WIDTH-1 : 0] s00_axi_rdata,
		output wire [1 : 0] s00_axi_rresp,
		output wire  s00_axi_rvalid,
		input wire  s00_axi_rready
	);
// Instantiation of Axi Bus Interface S00_AXI
	SD_DAC_v2_0_S00_AXI # ( 
		.C_S_AXI_DATA_WIDTH(C_S00_AXI_DATA_WIDTH),
		.C_S_AXI_ADDR_WIDTH(C_S00_AXI_ADDR_WIDTH)
	) SD_DAC_v2_0_S00_AXI_inst (	
        .ctrlReg(ctrlReg),
        .internalWriteReg(writeData),
        .internalWriteReq(writeReq),
        .internalWriteAck(writeAck),
		.S_AXI_ACLK(s00_axi_aclk),
		.S_AXI_ARESETN(s00_axi_aresetn),
		.S_AXI_AWADDR(s00_axi_awaddr),
		.S_AXI_AWPROT(s00_axi_awprot),
		.S_AXI_AWVALID(s00_axi_awvalid),
		.S_AXI_AWREADY(s00_axi_awready),
		.S_AXI_WDATA(s00_axi_wdata),
		.S_AXI_WSTRB(s00_axi_wstrb),
		.S_AXI_WVALID(s00_axi_wvalid),
		.S_AXI_WREADY(s00_axi_wready),
		.S_AXI_BRESP(s00_axi_bresp),
		.S_AXI_BVALID(s00_axi_bvalid),
		.S_AXI_BREADY(s00_axi_bready),
		.S_AXI_ARADDR(s00_axi_araddr),
		.S_AXI_ARPROT(s00_axi_arprot),
		.S_AXI_ARVALID(s00_axi_arvalid),
		.S_AXI_ARREADY(s00_axi_arready),
		.S_AXI_RDATA(s00_axi_rdata),
		.S_AXI_RRESP(s00_axi_rresp),
		.S_AXI_RVALID(s00_axi_rvalid),
		.S_AXI_RREADY(s00_axi_rready)
	);

	// Add user logic here
    wire [C_S00_AXI_DATA_WIDTH-1:0] ctrlReg;
    wire [C_S00_AXI_DATA_WIDTH-1:0] writeData;
    wire [15:0] dacDataIn;
    wire taskCkEn;
    wire taskStabConEn;
    wire ck;
    wire arst;
    wire internalRst;
    wire writeReq;
    wire writeAck;
    
    assign ck = s00_axi_aclk;
    assign arst = ~s00_axi_aresetn;
    assign dacDataIn = s00_axis_tdata[15:0];
    assign irqUnderflow = ~s00_axis_tvalid & s00_axis_tready;
    assign instabilityReset = internalRst;
    
    
    RegEventControl #(
        .DATA_WIDTH(C_S00_AXI_DATA_WIDTH)
        )
    u_RegEventControl(
        .ck(ck),
        .arst(arst),
        .writeAck(writeAck),
        .irqIn(irqUnderflow),
        .ctrlReg(ctrlReg),
        .writeData(writeData),
        .writeReq(writeReq)
        );
    
    RegTasks #(
        .DATA_WIDTH(C_S00_AXI_DATA_WIDTH)
        )
    u_RegTasks(
        .ck(ck),
        .arst(arst),
        .ctrlReg(ctrlReg),
        .taskCkEn(taskCkEn),
        .taskStabConEn(taskStabConEn)
        );
        
    dac u_dac(
        .ck(ck),  
        .rst(arst),
        .sdInternalRst(internalRst), 
        .ck_enable(taskCkEn),
        .dataIn(dacDataIn),
        .ce_out(s00_axis_tready),
        .dataOut(dacOut)
        );
     
    StabilityControlUnit u_StabilityControlUnit(
        .ck(ck),
        .enable(taskStabConEn),
        .rst(~s00_axi_aresetn),
        .sdOut(dacOut),
        .sdRst(internalRst)
        );
    
    // User logic ends

	endmodule
