//********************************************************************************
//                                                                                
//       Nordic Semiconductor ASA, Otto Nielsens vei 12, N-7004 TRONDHEIM, NORWAY
//                                                                                
//********************************************************************************
// Project name   :                                                        
// Project number :                                                        
// File type      : Verilog rtl.                                                  
// Designer       : Håkon Tobias Jøsok
// Description    : 3. order single loop single bit Sigma-Delta modulator for audio application
//
//               
//********************************************************************************


module sdMod #(parameter DATA_WIDTH_X1     = 31,
               parameter DATA_WIDTH_X2     = 31,
               parameter DATA_WIDTH_X3     = 31
              )
              ( 
               input   logic                              ck,
               input   logic                              rst,
               input   logic                              instabilityRst,
               input   logic                              ck_enable,
               input   logic signed [15:0]                u,
               output  logic                              v
               );
  
  // internal signals
  logic signed [DATA_WIDTH_X1-1:0]     x1;
  logic signed [DATA_WIDTH_X2-1:0]     x2;
  logic signed [DATA_WIDTH_X2-1:0]     x2Comb;
  logic signed [DATA_WIDTH_X3-1:0]     x3;
  logic signed [DATA_WIDTH_X3-1:0]     uExtend;
  logic signed [DATA_WIDTH_X3-1:0]     temp;
  logic signed [DATA_WIDTH_X3-1+3:0]   temp2;
  
  //Extend u to match data with of x1 
  assign uExtend = u;
  
  always_ff @(posedge ck) begin
    if (rst || instabilityRst) begin
      x1     <= 0;
      x2     <= 0;
      x3     <= 0;
      v      <= 0;
    end
    else begin
      if(ck_enable) begin
        x3 <= x3 + (x2Comb>>>3) + (x2Comb>>>4) + (x2Comb>>>5) - (temp<<17) - (temp<<16) - (temp<<15) - (temp<<13);
        x2 <= x2Comb;
        x1 <= x1 + (uExtend<<3) - (temp<<18);
        if(temp == 1)
          v <= 1;
        else
          v <= 0;
      end
    end
  end
  
  always_comb begin
    x2Comb = x2 + (x1>>>2) + (x1>>>4) + (x1>>>6) - (temp<<18) - (temp<<17) - (temp<<16) - (temp<<14) - (x3>>>10) - (x3>>>11) - (x3>>>13) - (x3>>>14);
  end
    
  always_comb begin
    temp2 = ((x3+(x3<<2)) >>> 21);
    if(temp2 >= 1) 
      temp = 1;
    else
      temp = -1;
  end
  
endmodule 